[TOC]

# Linux服务 (X86)
#### 下载地址
- 服务器上直接下载
```shell
[root@localhost]$ wget https://file.guthon.com/fileservice/download/guthon-servo-center-3.0.x86_64.rpm
```
- 安装包文件下载（离线安装包）：[guthon-servo-center-3.0.x86_64.rpm](https://file.guthon.com/fileservice/download/guthon-servo-center-3.0.x86_64.rpm)

#### 服务安装
- 下载安装包后，上传到服务器，并执行安装命令
```shell
[root@localhost]$ rpm -ivh guthon-servo-center-3.0.x86_64.rpm
```
- 安装参数：
 - 安装路径固定在 `/opt/guthon/servo-center` 目录，且不可更改。
 - 服务监听端口固定为`8086`且不可更改，安装服务会自动开启此端口防火墙访问。
 - 注册服务名称`servocenter`
- 访问地址：http://$ip:8086

#### 服务管理
安装程序会自动注册linux服务`servocenter`，您可以通过linux服务管理命令来管理此服务，管理命令操作如下：
```shell
[root@localhost]$ systemctl status servocenter
[root@localhost]$ systemctl start servocenter
[root@localhost]$ systemctl stop servocenter
```
> [info] 当操作系统重启时，本服务会随系统一起启动

#### 服务卸载
```shell
[root@localhost]$ systemctl stop servocenter
[root@localhost]$ rpm -e guthon-servo-center
```

# Windows
#### 下载地址
- 安装包文件下载（离线安装包）： [servocenter-setup-3.0.exe](https://file.guthon.com/fileservice/download/servocenter-setup-3.0.exe)

#### 服务安装
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;直接双击启动安装程序即可，安装程序会自动查找主机客户端服务的安装路径，并将安装路径设置为与主机客户端服务同路径。
- 安装参数：
 - 服务监听端口固定为`8086`且不可更改，安装服务会自动开启此端口防火墙访问。
 - 注册Windows服务名称`谷神运管平台管理中心服务`
- 访问地址：http://$ip:8086

#### 服务管理
安装程序会自动注册Windows服务`谷神运管平台管理中心服务`，您可以通过Windows的服务管理器来管理本服务。
> [info] 当操作系统重启时，本服务会随系统一起启动

#### 服务卸载
直接执行安装目录(如：D:\guthon\servocenter)下的卸载程序`uninst.exe`即可卸载本服务及已注册的Windows服务。

# 其他服务器（Unix、Mac或其他Linux架构，如：ARM、龙芯、RISC-V等）
#### 下载地址
- 服务器上直接下载
```shell
[root@localhost]$ wget https://file.guthon.com/fileservice/download/guthon-servo-center-3.0.zip
```
- 安装包文件下载（离线安装包）：[guthon-servo-center-3.0.zip](https://file.guthon.com/fileservice/download/guthon-servo-center-3.0.zip)

#### 服务安装
- 先确定客户端服务安装路径，如：/opt/guthon
- 上传安装包后，解压缩安装包：
```shell
[root@localhost]$ unzip guthon-servo-center-3.0.zip -d /opt/guthon
[root@localhost]$ cd /opt/guthon/servo-center
```
- 赋予可执行权限:
```shell
[root@localhost servo-center]$ chmod a+x service.sh
```
- 修改启动文件中JDK路径
```shell
[root@localhost]$ vi /opt/guthon/servo-center/service.sh
```
![](http://docs.guthon.com/uploads/gdfaas/images/m_6720ffb6b1785c0a7dc4d09925a7de03_r.png)


- 安装服务（以典型Linux系统为例，其他系统视各自配置规则）
```shell
[root@localhost servo-center]$ cp servocenter.service /usr/lib/systemd/system/servocenter.service
[root@localhost servo-center]$ systemctl enable servocenter.service
[root@localhost servo-center]$ systemctl daemon-reload
```
> [info] 注意： servocenter.service 文件里，默认安装路径为 /opt/guthon/servo-center 若您自定义了安装路径，则请修改此文件里的相关路径。

- 添加防火墙端口：服务监听端口固定为`8086`且不可更改，若您已开启本地操作系统的防火墙，则请开启端口访问：
```shell
[root@localhost]$ firewall-cmd --permanent --zone=public --add-port=8086/tcp
[root@localhost]$ firewall-cmd --reload
```

#### 服务管理
您可以通过linux服务管理命令来管理此服务，管理命令操作如下：
```shell
[root@localhost]$ systemctl status servocenter
[root@localhost]$ systemctl start servocenter
[root@localhost]$ systemctl stop servocenter
```
#### 服务卸载
直接删除安装目录以及相关服务即可.
```shell
[root@localhost]$ systemctl stop servocenter
[root@localhost]$ systemctl disable servocenter
[root@localhost]$ rm -f /usr/lib/systemd/system/servocenter.service
[root@localhost]$ systemctl daemon-reload
[root@localhost]$ rm -rf /opt/guthon/servo-center
```

> [warning] 请注意：
1、管理中心服务依赖于主机客户端服务，故安装管理中心服务前，请先安装主机客户端服务
2、管理中心服务监听端口为[8086]，请确保您服务器上没有此端口监听的服务
3、管理中心服务尽量不要公网访问，若要公网访问，请务必通过nginx反向代理，切不可直接把端口对公网映射，且要求所有操作人员的密码必须设置为复杂密码。

### 已发现的问题
1. 管理中心启动后，也初始化好了，到了登录页面，但是验证码无法显示
  - 这种情况可能是，在安装linux时，使用的最小安装，导致系统字体没有安装，需要手工安装字体，以下是以centos7为例：
```
[root@localhost] $ rpm -Uvh fontpackages-filesystem-1.44-8.el7.noarch.rpm
[root@localhost] $ rpm -Uvh dejavu-fonts-common-2.33-6.el7.noarch.rpm
[root@localhost] $ rpm -Uvh dejavu-sans-fonts-2.33-6.el7.noarch.rpm
[root@localhost] $ rpm -Uvh dejavu-serif-fonts-2.33-6.el7.noarch.rpm
[root@localhost] $ rpm -Uvh libpng-1.5.13-8.el7.x86_64.rpm
[root@localhost] $ rpm -Uvh freetype-2.8-14.el7.x86_64.rpm
[root@localhost] $ rpm -Uvh fontconfig-2.13.0-4.3.el7.x86_64.rpm
```
 - 相关资源下载(cnetos7，其他系统和版本自行下载)：[centos-font-config-7.x.zip](https://file.guthon.com/fileservice/download/centos-font-config-7.x.zip)